@@ -17,7 +17,7 @@ PATTERN_COMPILE_IGNORED = [
     re.compile(r'^/?boot\.py$', re.IGNORECASE),
 ]
 PATTERN_INCLUDE = [
-    re.compile(r'/\.mpypack_sha256.json$', re.IGNORECASE),
+    # re.compile(r'/\.mpypack_sha256.json$', re.IGNORECASE),
 ]
 PATTERN_EXCLUDE = [
     re.compile(r'/?__pycache__/?', re.IGNORECASE),
@@ -93,6 +93,7 @@ class FileSync():
                 #     continue # ignore hidden file
                 lst.append(file_pth)
         for f in lst.copy():
+            print(f)
             if not self.should_include(f, ignore_hidden):
                 lst.remove(f)
         return lst
@@ -215,6 +216,7 @@ class FileSync():
         makedirs(target_folder)
         new_file_record = {}
         for f in local_files:
+            print(f)
             # base info
             localpath = self.get_local_path(f)
             target = syspath.join(target_folder, PurePath(localpath).relative_to(self.__local))
